@@ -19,6 +19,7 @@ package org.drools.workbench.screens.guided.dtable.client.editor;
 import java.util.Collections;
 import java.util.List;
 import java.util.Set;
+import java.util.function.Consumer;
 import java.util.function.Supplier;
 
 import javax.annotation.PostConstruct;
@@ -29,6 +30,7 @@ import javax.inject.Inject;
 
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.user.client.ui.IsWidget;
+import elemental2.promise.Promise;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.EditMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuBuilder;
@@ -41,6 +43,7 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDeci
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
@@ -196,8 +199,8 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
 
     @Override
     @WorkbenchMenu
-    public Menus getMenus() {
-        return super.getMenus();
+    public void getMenus(final Consumer<Menus> menusConsumer) {
+        super.getMenus(menusConsumer);
     }
 
     @Override
@@ -218,28 +221,37 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
     }
 
     @Override
-    public void makeMenuBar() {
-        if (canUpdateProject()) {
-            getFileMenuBuilder()
-                    .addSave(getSaveMenuItem())
-                    .addCopy(() -> getActiveDocument().getCurrentPath(),
-                             assetUpdateValidator)
-                    .addRename(getSaveAndRenameCommand())
-                    .addDelete(() -> getActiveDocument().getLatestPath(),
-                               assetUpdateValidator);
+    public Promise<Void> makeMenuBar() {
+        if (workbenchContext.getActiveWorkspaceProject().isPresent()) {
+            final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().get();
+            return projectController.canUpdateProject(activeProject).then(canUpdateProject -> {
+                if (canUpdateProject) {
+                    getFileMenuBuilder()
+                            .addSave(getSaveMenuItem())
+                            .addCopy(() -> getActiveDocument().getCurrentPath(),
+                                     assetUpdateValidator)
+                            .addRename(getSaveAndRenameCommand())
+                            .addDelete(() -> getActiveDocument().getLatestPath(),
+                                       assetUpdateValidator);
+                }
+
+                final FileMenuBuilder fileMenuBuilder = getFileMenuBuilder()
+                        .addValidate(() -> onValidate(getActiveDocument()))
+                        .addNewTopLevelMenu(getEditMenuItem())
+                        .addNewTopLevelMenu(getViewMenuItem())
+                        .addNewTopLevelMenu(getInsertMenuItem())
+                        .addNewTopLevelMenu(getRadarMenuItem())
+                        .addNewTopLevelMenu(getVersionManagerMenuItem())
+                        .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+                addDownloadMenuItem(fileMenuBuilder);
+
+                this.menus = fileMenuBuilder.build();
+
+                return promises.resolve();
+            });
         }
 
-        final FileMenuBuilder fileMenuBuilder = getFileMenuBuilder()
-                .addValidate(() -> onValidate(getActiveDocument()))
-                .addNewTopLevelMenu(getEditMenuItem())
-                .addNewTopLevelMenu(getViewMenuItem())
-                .addNewTopLevelMenu(getInsertMenuItem())
-                .addNewTopLevelMenu(getRadarMenuItem())
-                .addNewTopLevelMenu(getVersionManagerMenuItem())
-                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
-        addDownloadMenuItem(fileMenuBuilder);
-
-        this.menus = fileMenuBuilder.build();
+        return promises.resolve();
     }
 
     protected Command getSaveAndRenameCommand() {
