@@ -20,6 +20,7 @@ import java.math.BigInteger;
 import java.util.Date;
 import java.util.List;
 
+import org.drools.workbench.models.datamodel.rule.HasOperator;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
@@ -83,7 +84,6 @@ import org.kie.soup.project.datamodel.oracle.OperatorsOracle;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.uberfire.ext.wires.core.grids.client.model.GridCell;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
-import org.uberfire.ext.wires.core.grids.client.widget.context.GridBodyCellRenderContext;
 import org.uberfire.ext.wires.core.grids.client.widget.dom.impl.CheckBoxDOMElement;
 import org.uberfire.ext.wires.core.grids.client.widget.dom.multiple.impl.CheckBoxDOMElementFactory;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
@@ -130,6 +130,17 @@ public abstract class BaseColumnConverterImpl implements BaseColumnConverter {
     protected GridColumn<?> newColumn(final BaseColumn column,
                                       final GuidedDecisionTablePresenter.Access access,
                                       final GuidedDecisionTableView gridWidget) {
+
+        if (column instanceof HasOperator && OperatorsOracle.operatorRequiresList(((HasOperator) column).getOperator())) {
+            return newStringColumn(makeHeaderMetaData(column),
+                                   Math.max(column.getWidth(),
+                                            DEFAULT_COLUMN_WIDTH),
+                                   true,
+                                   !column.isHideColumn(),
+                                   access,
+                                   gridWidget);
+        }
+
         //Get a column based upon the data-type
         final String type = columnUtilities.getType(column);
 
@@ -716,8 +727,7 @@ public abstract class BaseColumnConverterImpl implements BaseColumnConverter {
 
                                        @Override
                                        public CheckBoxDOMElement createDomElement(final GridLayer gridLayer,
-                                                                                  final GridWidget gridWidget,
-                                                                                  final GridBodyCellRenderContext context) {
+                                                                                  final GridWidget gridWidget) {
                                            final CheckBox widget = createWidget();
                                            widget.addMouseDownHandler((e) -> e.stopPropagation());
                                            widget.addKeyDownHandler((e) -> e.stopPropagation());
