@@ -31,12 +31,17 @@ import javax.enterprise.event.Event;
 import javax.inject.Inject;
 import javax.inject.Named;
 
-import org.drools.workbench.screens.scenariosimulation.backend.server.runner.ScenarioJunitActivator;
+import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
+import org.drools.scenariosimulation.api.model.ScenarioWithIndex;
+import org.drools.scenariosimulation.api.model.Simulation;
+import org.drools.scenariosimulation.api.model.SimulationDescriptor;
+import org.drools.scenariosimulation.backend.runner.ScenarioJunitActivator;
+import org.drools.scenariosimulation.backend.util.ImpossibleToFindDMNException;
+import org.drools.scenariosimulation.backend.util.ScenarioSimulationXMLPersistence;
 import org.drools.workbench.screens.scenariosimulation.backend.server.util.ScenarioSimulationBuilder;
-import org.drools.workbench.screens.scenariosimulation.model.Scenario;
-import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
 import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModelContent;
-import org.drools.workbench.screens.scenariosimulation.model.SimulationDescriptor;
+import org.drools.workbench.screens.scenariosimulation.model.SimulationRunResult;
+import org.drools.workbench.screens.scenariosimulation.service.DMNTypeService;
 import org.drools.workbench.screens.scenariosimulation.service.ScenarioRunnerService;
 import org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService;
 import org.drools.workbench.screens.scenariosimulation.type.ScenarioSimulationResourceTypeDefinition;
@@ -71,6 +76,8 @@ import org.uberfire.java.nio.file.FileAlreadyExistsException;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.workbench.events.ResourceOpenedEvent;
 
+import static org.drools.scenariosimulation.api.model.ScenarioSimulationModel.Type;
+
 @Service
 @ApplicationScoped
 public class ScenarioSimulationServiceImpl
@@ -120,6 +127,9 @@ public class ScenarioSimulationServiceImpl
     @Inject
     protected ScenarioSimulationBuilder scenarioSimulationBuilder;
 
+    @Inject
+    protected DMNTypeService dmnTypeService;
+
     private SafeSessionInfo safeSessionInfo;
 
     private Properties props = new Properties();
@@ -150,13 +160,13 @@ public class ScenarioSimulationServiceImpl
     }
 
     @Override
-    public Map<Integer, Scenario> runScenario(final Path path,
-                                               final SimulationDescriptor simulationDescriptor,
-                                               final Map<Integer, Scenario> scenarioMap) {
+    public SimulationRunResult runScenario(final Path path,
+                                           final SimulationDescriptor simulationDescriptor,
+                                           final List<ScenarioWithIndex> scenarios) {
         return scenarioRunnerService.runTest(user.getIdentifier(),
                                              path,
                                              simulationDescriptor,
-                                             scenarioMap);
+                                             scenarios);
     }
 
     @Override
@@ -164,11 +174,11 @@ public class ScenarioSimulationServiceImpl
                        final String fileName,
                        final ScenarioSimulationModel content,
                        final String comment) {
-        return create(context, fileName, content, comment, ScenarioSimulationModel.Type.RULE, "default");
+        return create(context, fileName, content, comment, Type.RULE, null);
     }
 
     @Override
-    public Path create(Path context, String fileName, ScenarioSimulationModel content, String comment, ScenarioSimulationModel.Type type, String value) {
+    public Path create(Path context, String fileName, ScenarioSimulationModel content, String comment, Type type, String value) {
         try {
             content.setSimulation(scenarioSimulationBuilder.createSimulation(context, type, value));
             final org.uberfire.java.nio.file.Path nioPath = Paths.convert(context).resolve(fileName);
@@ -195,7 +205,19 @@ public class ScenarioSimulationServiceImpl
         try {
             final String content = ioService.readAllString(Paths.convert(path));
 
-            return ScenarioSimulationXMLPersistence.getInstance().unmarshal(content);
+            ScenarioSimulationModel scenarioSimulationModel = unmarshalInternal(content);
+            Simulation simulation = scenarioSimulationModel.getSimulation();
+            if(simulation != null && Type.DMN.equals(simulation.getSimulationDescriptor().getType())) {
+                try {
+                    dmnTypeService.initializeNameAndNamespace(simulation,
+                                                              path,
+                                                              simulation.getSimulationDescriptor().getDmnFilePath());
+                } catch (ImpossibleToFindDMNException e) {
+                    // this error is not thrown so user can fix the file path manually
+                    logger.error(e.getMessage(), e);
+                }
+            }
+            return scenarioSimulationModel;
         } catch (Exception e) {
             throw ExceptionUtilities.handleException(e);
         }
@@ -218,8 +240,8 @@ public class ScenarioSimulationServiceImpl
         consumedFQCNs.addAll(oracle.getModuleCollectionTypes()
                                      .entrySet()
                                      .stream()
-                                     .filter(entry -> entry.getValue())
-                                     .map(entry -> entry.getKey())
+                                     .filter(Map.Entry::getValue)
+                                     .map(Map.Entry::getKey)
                                      .collect(Collectors.toSet()));
 
         DataModelOracleUtilities.populateDataModel(oracle,
@@ -241,18 +263,14 @@ public class ScenarioSimulationServiceImpl
                      final Metadata metadata,
                      final String comment) {
         try {
-            final Metadata currentMetadata = metadataService.getMetadata(resource);
             ioService.write(Paths.convert(resource),
                             ScenarioSimulationXMLPersistence.getInstance().marshal(content),
                             metadataService.setUpAttributes(resource,
                                                             metadata),
                             commentedOptionFactory.makeCommentedOption(comment));
 
-            fireMetadataSocialEvents(resource,
-                                     currentMetadata,
-                                     metadata);
-
             createActivatorIfNotExist(resource);
+
             return resource;
         } catch (Exception e) {
             throw ExceptionUtilities.handleException(e);
@@ -326,15 +344,17 @@ public class ScenarioSimulationServiceImpl
         Package junitActivatorPackage = getOrCreateJunitActivatorPackage(kieModule);
         final org.uberfire.java.nio.file.Path activatorPath = getActivatorPath(junitActivatorPackage);
 
-        if (!ioService.exists(activatorPath)) {
+        boolean needMigrateActivatorIfExists = ensureDependencies(kieModule);
+
+        // junit activator needs to be created if the project has old dependencies or activator doesn't exist
+        if (needMigrateActivatorIfExists || !ioService.exists(activatorPath)) {
+            // first remove existing activators (if exist)
+            removeOldActivatorIfExists(activatorPath, kieModule);
+
             ioService.write(activatorPath,
                             ScenarioJunitActivator.ACTIVATOR_CLASS_CODE.apply(junitActivatorPackageName),
                             commentedOptionFactory.makeCommentedOption(""));
-
-            removeOldActivatorIfExists(kieModule);
         }
-
-        ensureDependencies(kieModule);
     }
 
     protected Package getOrCreateJunitActivatorPackage(KieModule kieModule) {
@@ -347,8 +367,17 @@ public class ScenarioSimulationServiceImpl
         return junitActivatorPackage;
     }
 
-    protected void removeOldActivatorIfExists(KieModule kieModule) {
+    /**
+     * This routine looks for existing activators to migrate
+     * @param activatorPath
+     * @param kieModule
+     */
+    protected void removeOldActivatorIfExists(org.uberfire.java.nio.file.Path activatorPath, KieModule kieModule) {
 
+        // migration step after Test Scenario runner modules split DROOLS-3389
+        ioService.deleteIfExists(activatorPath);
+
+        // migration step after Test Scenario activator package fix RHPAM-1923
         String targetPackageName = kieModule.getPom().getGav().getGroupId();
 
         Optional<Package> packageFound = kieModuleService.resolvePackages(kieModule).stream()
@@ -360,7 +389,12 @@ public class ScenarioSimulationServiceImpl
         });
     }
 
-    protected void ensureDependencies(KieModule module) {
+    /**
+     * Verify if the project contains all the needed dependencies removing the old ones if available
+     * @param module
+     * @return boolean that specify if there was old dependencies
+     */
+    protected boolean ensureDependencies(KieModule module) {
         POM projectPom = module.getPom();
         Dependencies dependencies = projectPom.getDependencies();
 
@@ -368,6 +402,13 @@ public class ScenarioSimulationServiceImpl
 
         boolean toSave = false;
         Path modulePomXMLPath = module.getPomXMLPath();
+
+        for (GAV oldDependency : getOldDependencies()) {
+            toSave |= removeFromPomIfNecessary(dependencies, oldDependency);
+        }
+
+        boolean oldDependenciesExist = toSave;
+
         for (GAV gav : getDependencies(kieVersion)) {
             toSave |= editPomIfNecessary(dependencies, gav);
         }
@@ -375,6 +416,19 @@ public class ScenarioSimulationServiceImpl
         if (toSave) {
             pomService.save(modulePomXMLPath, projectPom, null, "");
         }
+
+        return oldDependenciesExist;
+    }
+
+    protected boolean removeFromPomIfNecessary(Dependencies dependencies, GAV oldDependency) {
+        for (Dependency dependency : dependencies) {
+            if (dependency.getGroupId().equals(oldDependency.getGroupId()) &&
+                    dependency.getArtifactId().equals(oldDependency.getArtifactId())) {
+                dependencies.remove(dependency);
+                return true;
+            }
+        }
+        return false;
     }
 
     protected boolean editPomIfNecessary(Dependencies dependencies, GAV gav) {
@@ -395,15 +449,26 @@ public class ScenarioSimulationServiceImpl
         return internalGetPath(rootModulePackage, junitActivatorPackageName);
     }
 
+    protected List<GAV> getOldDependencies() {
+        return Arrays.asList(new GAV("org.drools", "drools-wb-scenario-simulation-editor-api", null),
+                             new GAV("org.drools", "drools-wb-scenario-simulation-editor-backend", null));
+    }
+
     protected List<GAV> getDependencies(String kieVersion) {
-        return Arrays.asList(new GAV("org.drools", "drools-wb-scenario-simulation-editor-api", kieVersion),
-                             new GAV("org.drools", "drools-wb-scenario-simulation-editor-backend", kieVersion),
+        return Arrays.asList(new GAV("org.drools", "drools-scenario-simulation-api", kieVersion),
+                             new GAV("org.drools", "drools-scenario-simulation-backend", kieVersion),
                              new GAV("org.drools", "drools-compiler", kieVersion),
+                             // needed to compile guided decision table
+                             new GAV("org.drools", "drools-workbench-models-guided-dtable", kieVersion),
                              new GAV("org.kie", "kie-dmn-feel", kieVersion),
                              new GAV("org.kie", "kie-dmn-api", kieVersion),
                              new GAV("org.kie", "kie-dmn-core", kieVersion));
     }
 
+    protected ScenarioSimulationModel unmarshalInternal(String content) {
+        return ScenarioSimulationXMLPersistence.getInstance().unmarshal(content);
+    }
+
     private org.uberfire.java.nio.file.Path internalGetPath(Package pkg, String path) {
         org.uberfire.java.nio.file.Path packagePath = Paths.convert(pkg.getPackageTestSrcPath());
         return packagePath.resolve(path);
